@@ -830,7 +830,7 @@ epsfn = function(A, e, b, n.ahead, ed)
 	}
 	# some checks
 	if(is.na(rseed[1])){
-		sseed = as.integer(runif(1,0,as.integer(Sys.time())))
+    sseed = NA
 	} else{
 		if(length(rseed) != m.sim) sseed = as.integer(rseed[1]) else sseed = rseed[1:m.sim]
 	}
@@ -1020,7 +1020,7 @@ epsfn = function(A, e, b, n.ahead, ed)
 	}
 	# some checks
 	if(is.na(rseed[1])){
-		sseed = as.integer(runif(1,0,as.integer(Sys.time())))
+    sseed = NA
 	} else{
 		if(length(rseed) != m.sim) sseed = as.integer(rseed[1]) else sseed = rseed[1:m.sim]
 	}
