@@ -16,7 +16,7 @@
 #################################################################################
 
 #################################################################################
-# Fitting tests
+# Fitting (estimation) tests
 #################################################################################
 
 rugarch.test3a = function(cluster=NULL)
@@ -193,7 +193,7 @@ rugarch.test3b = function(cluster=NULL)
 	# convert to matrix which is what the specification expects
 	monday = matrix(monday, ncol = 1)
 	# create a dummy day-of-week variable for the variance regression (Friday)
-	friday = rugarch:::WeekDayDummy(dates, date.format = "%Y-%m-%d", weekday = "Friday")
+	friday = rugarch:::.WeekDayDummy(dates, date.format = "%Y-%m-%d", weekday = "Friday")
 	# convert to matrix which is what the specification expects
 	friday = matrix(friday, ncol = 1)
 	# sGARCH(1,1)
@@ -318,11 +318,11 @@ rugarch.test3c = function(cluster=NULL)
 	
 	data(dji30ret)
 	dates = rownames(dji30ret[,"AA", drop = FALSE])
-	monday = rugarch:::WeekDayDummy(dates, date.format = "%Y-%m-%d", weekday = "Monday")
+	monday = rugarch:::.WeekDayDummy(dates, date.format = "%Y-%m-%d", weekday = "Monday")
 	# convert to matrix which is what the specification expects
 	monday = matrix(monday, ncol = 1)
 	# create a dummy day-of-week variable for the variance regression (Friday)
-	friday = rugarch:::WeekDayDummy(dates, date.format = "%Y-%m-%d", weekday = "Friday")
+	friday = rugarch:::.WeekDayDummy(dates, date.format = "%Y-%m-%d", weekday = "Friday")
 	# convert to matrix which is what the specification expects
 	friday = matrix(friday, ncol = 1)
 	# apARCH(1,1)
